/**
 * Name        : main.c
 * Version     : V 1.0
 * Description : Programa Principal BoyaPrototipo
 * 				 Entrega Final TFC
 */

#ifdef __USE_CMSIS
#include "LPC17xx.h"
#endif
#include "FreeRTOS.h"
#include "logTerminal.h"
#include "adc.h"
#include "timers.h"
#include "queue.h"
#include "semphr.h"


//****** ADC variables and arrays ******//
uint32_t adc_result[5][2];	// 5 canales para ADC, con su identificador de sensor y su valor digital del ADC
float temperatura; // Pruebas prototipo con Temperatura
float voltage;

//Tareas
static void vRunBoya( void *pvParameters );
static void vRunReadSensors( void *pvParameters );
static void vRunSendDataSensors( void *pvParameters );

//Handlers
xTimerHandle xTimerClock;									//Timer handler
xQueueHandle xQueueCola;									//Queue handler
xSemaphoreHandle xMutexWiFly;

//identificadores
int idBoya = 11;
int idsSensores[5];


int main(void)
{
	// Preparo idntificadores
	// En prototipo solo se usa un canal de los cinco.
	// El primer canal se utiliza para  la Temperatura del prototipo.
	// En un producto final se editaran las cuatro posiciones sobrantes.
	idsSensores[0] = 5; // en este caso el identificador es igual que el id de sensor en la BBDD
	idsSensores[1] = 0; // idle
	idsSensores[2] = 0; // idle
	idsSensores[3] = 0; // idle
	idsSensores[4] = 0; // idle

	adc_result[0][0] = idsSensores[0];
	adc_result[1][0] = idsSensores[1];
	adc_result[2][0] = idsSensores[2];
	adc_result[3][0] = idsSensores[3];
	adc_result[4][0] = idsSensores[4];

	// Preparo Terminal para Debug en PC con CP2102 conectado a mota
	logTerminalInit();
	//Creamos los mutex para acceder a la WiFly
	xMutexWiFly = xSemaphoreCreateMutex();

	logTerminal("Arrancando Sistema Adquisicion Boya ....");
	// Cola para pasar lecturas ADC (5 posiciones, una para cada sensor)
	xQueueCola = xQueueCreate(5, sizeof(float));
	if (xQueueCola != NULL ) {
		xTaskCreate(vRunReadSensors,(signed char *) "Tarea Lectura Sensores Boya", 500, NULL, 2, NULL);
		xTaskCreate(vRunSendDataSensors,(signed char *) "Tarea Envio Sensores Boya", 500, NULL, 3, NULL);
	}
	else {
		logTerminal("No se ha podido crear la cola para el intercambio de lecturas sensores entre tareas.");
	}



	/* Arranca el Scheduler de Tareas*/
	vTaskStartScheduler();

	/* Si todo va bien nunca vamos a llegar aquí con el planificador corriendo.
	 * Si lo hacemos llegar aquí, entonces lo más probable es que no haya suficiente
	 * heap disponible para la tarea que se creará.*/
	for (;;);
	return 0;


}

void vRunReadSensors(void *pvParameters) {

	uint32_t valor;
	portTickType xLastWakeTime;


	char bufferRespuesta[500];
	bufferClear(bufferRespuesta, 500);

	xLastWakeTime = xTaskGetTickCount();

	ADCInit(2000000); //2 MHZ clock rate

	for (;;) {
		// Para prueba Piloto solo se lee el primer canal
		// Cuando se añadan sensores a la boya, se debera de utilizar un for para lecturas y calculos de cada sensor.
		adc_result[0][1] = ADC0Read(0);
		valor = adc_result[0][1];
		voltage = (float) (valor * 3300.0) / (float) 4095.0;
		temperatura = (float) (voltage - 500) / (float) 10; // 500 es el offset y 10 es el factor de escala
		//logTerminalFloat((char *) "voltage     --> %.2f mV", voltage);
		logTerminalFloat((char *) "Leido Sensor Temperatura --> %.2f Grados Centigrados", temperatura);
		delayMs(100);
		if (valor > 0) {
			if (xQueueCola != 0) {
				// Send a float number.  Wait for 10 ticks for space to become
				// available if necessary.
				if (xQueueSend(xQueueCola, &temperatura, 0) != pdPASS) {
					// Failed to post the message.
					logTerminal((char *) "Error -> No se ha podido añadir nuevo dato a la cola, aun despues de 10 ticks.");
				}
				else {
					//El ratio de lectura es de un minuto
					delayMsUntil(60000, &xLastWakeTime);
				}

			}
		}
	}
}

void vRunSendDataSensors(void *pvParameters) {

	float num;

	portBASE_TYPE xStatus;
	const portTickType xTicksToWait = 60000 / portTICK_RATE_MS;


	// Cada vez que enviemos datos, abrimos y cerramos conexion con el servidor
	for (;;) {

		xStatus = xQueueReceive(xQueueCola, &num, ( portTickType ) xTicksToWait);
		if (xStatus == pdPASS) {
			logTerminalFloat((char *) "Recibido de la cola Sensor Temperatura --> %.2f Grados Centigrados",num);
			// Configuracion Servidor RaspberryPi
			serverConf();
			// Establecemos conexion TCP con Servidor ograciasa.redirectme.net puerto 8082
			arpALabOpen();
			// Cogemos valor de la cola
			// Enviamos dato
			arpALabSendDatof(&num);
			sendDatoBBDDf(adc_result[0][0], &num);
			logTerminalFloat((char *) "Enviado Sensor Temperatura --> %.2f Grados Centigrados",num);
			arpALabClose();
		} else {
			logTerminal("No se recibe ningun dato de la cola");
		}
	}

}

/*-----------------------------------------------------------*/

void vApplicationIdleHook(void) {
	/* This example does not use the idle hook to perform any processing. */
}
/*-----------------------------------------------------------*/

void vApplicationTickHook(void) {
	/* This example does not use the tick hook to perform any processing. */
}

void vApplicationMallocFailedHook(void) {
	/* This function will only be called if an API call to create a task, queue
	 or semaphore fails because there is too little heap RAM remaining. */

	for (;;)
		;
}
/*-----------------------------------------------------------*/

