/*
===============================================================================
 Name        : UARTprintf.h
 Author      : Oscar Garcia Sanchez
 Version     : 1.0
 Copyright   : none
 Description : UARTprintf Headers
===============================================================================
*/

/*-----------------------------------------------------------
 * MACROS AND DEFINITIONS
 *----------------------------------------------------------*/
#define UART_OUTPUT_TERMINAL	3
#define UART_OUTPUT_BR			9600
#define UART_CR_LF				"\n\r"

/*
 * 		Clears the UART input buffer passed as parameter
 *
 * 		@param uartNum: is the number of the UART to send
 *
 * 		@return void
 */
void UARTClear(uint32_t uartNum);

/*
 * 		Read the UART input buffer passed as parameter.
 *
 * 		@param uartNum: is the number of the UART to receive
 * 		@param uartRecBuffer: is the received string
 *
 * 		@return void
 */
uint32_t UARTScanf(uint32_t uartNum, char* uartRecBuffer, uint32_t timeout);

/*
 * 		Send to UART a string passed as parameter
 *
 * 		@param uartNum: is the number of the UART to send
 * 		@param uartSendBuffer: is the sending string
 *
 * 		@return void
 */
void UARTprintf(uint32_t uartNum, char* uartSendBuffer);

/*
 * 		Send a string terminated with a newline passed as a parameter to UART
 *
 * 		@param uartNum: is the number of the UART to send
 * 		@param uartSendBuffer: is the sending string
 *
 * 		@return void
 */
void UARTprintfln(uint32_t uartNum, char* uartSendBuffer);

/*
 * 		Send a formatted string with a number passed as a parameter to UART terminated with a newline
 *
 * 		@param uartNum: is the number of the UART to send.
 * 		@param uartSendBuffer: is the sending string.
 *		@param number: is the number to format in the string.
 *
 * 		@return void
 *
 */
void UARTprintfnmbrln(uint32_t uartNum, char* uartSendBuffer, uint16_t number);

/*
 * 		Send a formatted string with a number passed as a parameter to UART terminated with a newline
 *
 * 		@param uartNum: is the number of the UART to send.
 * 		@param uartSendBuffer: is the sending string.
 *		@param number: is the number to format in the string.
 *
 * 		@return void
 *
 */
void UARTprintfnmbrfloatln(uint32_t uartNum, char* uartSendBuffer, float number);

/*
 * 		Send a formatted string with a number passed as a parameter to UART
 *
 * 		@param uartNum: is the number of the UART to send.
 * 		@param uartSendBuffer: is the sending string.
 *		@param number: is the number to format in the string.
 *
 * 		@return void
 *
 */
void UARTprintfnmbr(uint32_t uartNum, char* cadena, uint16_t numero);

/*
 * 		Make a active pause on the task
 *
 * 		@param ms: number of miliseconds to delay.
 *
 * 		@return void
 *
 */
void delayMs(uint32_t ms);

 /*
 * 		Clean buffer passed as parameter
 *
 * 		@param bufferToClean es el buffer a limpiar
 * 		@param sizebufferToClean es la longitud del buffer
 *
 * 		@return void
 */
void bufferClear(char* bufferToClean, uint16_t sizebufferToClean);
