/*
===============================================================================
 Name        : WiFly.h
 Author      : Oscar Garcia Sanchez
 Version     : 1.0
 Copyright   : none
 Description : Wifly Module Functions Definitions
===============================================================================
*/

/*-----------------------------------------------------------
 * MACROS AND DEFINITIONS
 *----------------------------------------------------------*/
//WiFly
#define WF_UART							0
#define WF_DEFAULT_BR					57600
#define WF_RST_PIN						22

//Network
//#define WF_WLAN_SSID					"iPhone$de$Oscar"
#define WF_WLAN_SSID					"APC"
#define WF_WLAN_AUTH_MODE_OPEN			0
#define WF_WLAN_AUTH_MODE_WEP			1
#define WF_WLAN_AUTH_MODE_WPA			2
#define WF_WLAN_PASS					"xxx"
//#define WF_WLAN_PASS					"xxx"

//Timeouts
#define WF_DEFAULT_TIMEOUT						1000
#define WF_SET_TIMEOUT							50
#define WF_LONG_TIMEOUT							4000
#define WF_JOIN_TIMEOUT							10000
#define WF_DOUBLE_TIMEOUT						2000

//Commands

//Action Commands
#define WF_COM_ACT_ENTER				"$$$"						//done
#define WF_COM_ACT_CLOSE				"close"						//to-do
#define WF_COM_ACT_EXIT					"exit"						//done
#define WF_COM_ACT_FACTORY_RESET		"factory RESET"				//to-do
#define WF_COM_ACT_JOIN_NUMBER			"join #%s"					//to-do
#define WF_COM_ACT_JOIN_SSID			"join "						//done
#define WF_COM_ACT_LEAVE				"leave"						//to-do
#define WF_COM_ACT_LITES				"lites"						//to-do
#define WF_COM_ACT_LOOKUP				"lookup %s"					//to-do
#define WF_COM_ACT_OPEN					"open arpalab.appspot.com 80"	  	  //done
#define WF_COM_ACT_OPEN_RASP			"open ogarciasa.redirectme.net 8082"  //done
#define WF_COM_ACT_PING					"ping %s %d"				//done
#define WF_COM_ACT_REBOOT				"reboot"					//done
#define WF_COM_ACT_SCAN					"scan"						//to-do
#define WF_COM_ACT_SLEEP				"sleep"						//to-do
#define WF_COM_ACT_TIME					"time"						//to-do
#define WF_COM_ACT_SAVE					"save"						//done

//Status Commands
#define WF_COM_SHOW_CONNECTION			"show connection"			//to-do
#define WF_COM_SHOW_IO					"show io"					//to-do
#define WF_COM_SHOW_NET					"show net"					//to-do
#define WF_COM_SHOW_NET_N				"show net n"				//to-do
#define WF_COM_SHOW_RSSI				"show rssi"					//done
#define WF_COM_SHOW_STATS  				"show stats"				//to-do
#define WF_COM_SHOW_TIME   				"show time"					//to-do

//Get Commands
#define WF_COM_GET_ADHOC				"get adhoc"					//to-do
#define WF_COM_GET_BROADCAST			"get broadcast"				//to-do
#define WF_COM_GET_COM					"get com"					//to-do
#define WF_COM_GET_DNS					"get dns"					//to-do
#define WF_COM_GET_EVERYTHING			"get everything"			//to-do
#define WF_COM_GET_FTP					"get ftp"					//to-do
#define WF_COM_GET_IP					"get ip"					//done
#define WF_COM_GET_CURRENT_IP			"get ip a"					//to-do
#define WF_COM_GET_MAC					"get mac"					//to-do
#define WF_COM_GET_OPTION				"get option"				//to-do
#define WF_COM_GET_SYS					"get sys"					//to-do
#define WF_COM_GET_TIME					"get time"					//to-do
#define WF_COM_GET_WLAN					"get wlan"					//to-do
#define WF_COM_GET_UART					"get uart"
#define WF_COM_GET_VERSION				"ver"

//Set Commands
#define WF_COM_SET_WLAN_AUTH_OPEN		"set wlan auth 0"			//done
#define WF_COM_SET_WLAN_SSID			"set wlan ssid %s"			//done
#define WF_COM_SET_WLAN_AUTH_WEP		"set wlan auth 1"			//done
#define WF_COM_SET_WLAN_AUTH_WPA		"set wlan auth 2"			//done
#define WF_COM_SET_WLAN_PHRASE			"set wlan phrase "			//done
#define WF_COM_SET_WLAN_KEY				"set wlan key "				//done
#define WF_COM_SET_WLAN_JOIN			"set wlan join %d"			//to-do
#define WF_COM_SET_IP_ADDRESS			"set ip address 192.168.1.118"	//done
#define WF_COM_SET_IP_MASK				"set ip netmask 255.255.255.0"	//done
#define WF_COM_SET_IP_GATEWAY			"set ip gateway 192.168.1.1"	//done
#define WF_COM_SET_DNS_ADDRESS			"set dns address 8.8.8.8"	//done




#define WF_COM_SET_IP_PROTO_HTTP		"set ip proto 18"			//done
#define WF_COM_SET_IP_DHCP				"set ip dhcp %d"			//to-do
#define WF_COM_SET_IP_DHCP_ZERO			"set ip dhcp 0"				//done
#define WF_COM_SET_IP_DNS_RESOLV		"set ip host 0"				//done
#define WF_COM_SET_IP_REMOTE_HTTP		"set ip remote 80"			//done
#define WF_COM_SET_DNS_NAME				"set dns name %s"			//done
#define WF_COM_SET_COM_REMOTE_ZERO		"set com remote 0"			//done
#define WF_COM_SET_COM_REMOTE			"set com remote %s" 		//done
#define WF_COM_SET_UART_BAUD			"set uart baud %d"			//done
#define WF_COM_SET_UART_MODE_TWO		"set uart mode 2"			//done
#define WF_COM_SET_OPTION_FORMAT_ZERO	"set option format 0"		//done
#define WF_COM_SET_OPTION_FORMAT_ONE	"set option format 1"		//done


//Functions Definitions

/*
 * 		Send Command to WiFly Module
 *
 * 		@param command: command to send.
 * 		@param bufferResponse: stores the response from the WiFly.
 *		@param timeout: time to wait for the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly
 */
uint32_t wiflySendCommand(char* command, char* bufferResponse, uint16_t timeout);

/*
 * 		Reset Wifly Module
 *
 * 		@param void
 *
 * 		@return void
 */
void wiFlyReset();

/*
 * 		Init Wifly Module
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly
 */
uint32_t wiFlyInit(char* bufferResponse);


//Functions Action Commands

/*
 * 		Login CMD Mode
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyEnter(char* bufferResponse);

/*
 * 		Logout CMD Mode
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyExit(char* bufferResponse);

/*
 * 		Join to WLAN
 *
 * 		@param bufferResponse: store the response from the WiFly.
 * 		@param ssid: SSID name of WLAN to connect.
 * 		@param authmode (0 = open, 1 = wep, 2= wpa).
 *
 * 		@return void
 */
void wiFlyJoinWLAN(char* bufferResponse, char* ssid, int authmode, char* pass);

/*
 * 		Ping to IP passed as parameter.
 *
 * 		@param bufferResponse: store the response from the WiFly.
 * 		@param ip: is the address at which to make ping.
 * 		@param numPings: is the number of pings to be performed.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyPing(char* bufferResponse, char* ip, int numPings);


//Functions Status Commands

/*
 * 		Shows the value of RSSI of the Wifly.
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyShowRSSI(char* bufferResponse);


//Functions Get Commands

/*
 * 		Show the IP assigned to the WiFly
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyGetIP(char* bufferResponse);

/*
 * 		Show channel now used by the WiFly
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlyGetChannel(char* bufferResponse);

/*
 * 		Show the operation time of the WiFly.
 *
 * 		@param bufferResponse: store the response from the WiFly.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t WiFlyShowUpTime(char* bufferResponse);


//Functions SET Commands

/*
 * 		Change the WiFly BuadRate
 *
 * 		@param bufferResponse: store the response from the WiFly.
 * 		@param newBR: new Baudrate to use by the Wifly Module.
 *
 * 		@return sizelength of the response of the WiFly.
 */
uint32_t wiFlySetBaudRate(char* bufferResponse, uint16_t newBR);
