/*
===============================================================================
 Name        : UARTprintf.c
 Author      : Oscar Garcia Sanchez
 Version     : 1.0
 Copyright   : none
 Description : UARTprintf Implementation
===============================================================================
*/
#include "stdio.h"
#include "string.h"
#include "type.h"
#include "uart.h"
#include "FreeRTOS.h"
#include "task.h"
#include "LPC17xx.h"

#include "UARTprintf.h"

const char str_ln[3] = {0x0D, 0x0A, 0x00};

extern volatile uint32_t UART0Count;
extern volatile uint8_t UART0Buffer[BUFSIZE];

void delayMs(uint32_t ms)
{
	const portTickType xDelay = ms / portTICK_RATE_MS;

	vTaskDelay( xDelay );
}

void delayMsUntil(uint32_t ms, portTickType xLastWakeTime)
{
	const portTickType xDelay = ms / portTICK_RATE_MS;

	vTaskDelayUntil(xLastWakeTime, xDelay);
}

void bufferClear(char* buffer, uint16_t sizeBuffer)
{
	memset( (char* )buffer, '\0', sizeBuffer );
}

void UARTClear(uint32_t uartNum)
{
	if(uartNum == 0)
	{
		UART0Count = 0;
		bufferClear((char *)UART0Buffer, 2000 );
	}
}

uint32_t UARTScanf(uint32_t uartNum, char* cadena, uint32_t timeout)
{
	uint32_t oldCount, newCount;

	if(uartNum == 0)
	{
		UART0Count = 0;
		LPC_UART0->IER= IER_THRE | IER_RLS | IER_RBR; //enable interrupt RX UART0
		delayMs(timeout); // wait sometime for receive some commands

		do
		{
			oldCount = newCount;
			delayMs(5);
			newCount = UART0Count;
		}
		while(oldCount != newCount); // wait a little time while we have new chars

		LPC_UART0->IER= IER_THRE | IER_RLS; // disable interrupt RX UART3

		strncpy(cadena, (char*)UART0Buffer, UART0Count);
		cadena[newCount] = '\0'; // add end string. Now we have a string

		UARTClear(0);
	}

	return newCount;
}

void UARTprintfln(uint32_t uartNum, char* string)
{
	UARTSend(uartNum, (uint8_t *)string, strlen(string));
	UARTSend(uartNum, (uint8_t *)str_ln, 2);
}

void UARTprintf(uint32_t uartNum, char* string)
{
	UARTSend(uartNum, (uint8_t *)string, strlen(string));
}

void UARTprintfnmbrln(uint32_t uartNum, char* string, uint16_t num)
{
	char bufferSend[500];
	bufferClear(bufferSend, 500);

	sprintf(bufferSend, string, num);
	strcat(bufferSend, str_ln); // \r\n
	UARTSend(uartNum, (uint8_t *)bufferSend, strlen(bufferSend));
}

void UARTprintfnmbrfloatln(uint32_t uartNum, char* string, float num)
{
	char bufferSend[500];
	bufferClear(bufferSend, 500);

	sprintf(bufferSend, string, num);
	strcat(bufferSend, str_ln); // \r\n
	UARTSend(uartNum, (uint8_t *)bufferSend, strlen(bufferSend));
}


void UARTprintfnmbr(uint32_t uartNum, char* string, uint16_t num)
{
	char bufferSend[500];
	bufferClear(bufferSend, 500);

	sprintf(bufferSend, string, num);
	UARTSend(uartNum, (uint8_t *)bufferSend, strlen(bufferSend));
}
