/*
===============================================================================
 Name        : WiFly.c
 Author      : Oscar Garcia Sanchez
 Version     : 1.0
 Copyright   : none
 Description : Wifly Module Functions Implementation
===============================================================================
*/

#include "stdio.h"
#include "string.h"
#include "type.h"
#include "uart.h"
#include "LPC17xx.h"

#include "UARTprintf.h"
#include "WiFly.h"


uint32_t wiflySendCommand(char* command, char* bufferResponse, uint16_t timeout)
{
	uint32_t lenghtResponse;
	
	UARTprintfln(WF_UART, command);
	lenghtResponse = UARTScanf(WF_UART, bufferResponse, timeout);

	return lenghtResponse;
}

void wiFlyReset()
{
	//Init pin 24 of LPC17xx Module
	LPC_PINCON->PINSEL1 &= ( ~( 3 << 12 ) );
	LPC_GPIO0->FIODIR |= ( 1 << WF_RST_PIN );

	//Reset To Wifly
	LPC_GPIO0->FIOCLR = 1 << WF_RST_PIN;
	delayMs(1000);
	LPC_GPIO0->FIOSET = 1 << WF_RST_PIN;
}

uint32_t wiFlyInit(char* bufferResponse)
{
	uint32_t lenghtResponse;

	UARTClear(WF_UART);
	UARTInit(WF_UART,WF_DEFAULT_BR);
	delayMs(3000); 	// Wait to the UART Initialization
	wiFlyReset();	// Reset Wifly
	lenghtResponse = UARTScanf(WF_UART, bufferResponse, WF_LONG_TIMEOUT);

	return lenghtResponse;
}


//Functions Action Commands

uint32_t wiFlyEnter(char* bufferRespuesta)
{
	uint32_t lenghtResponse;
	UARTprintf(WF_UART, WF_COM_ACT_ENTER);
	delayMs(300);
	lenghtResponse = UARTScanf(WF_UART, bufferRespuesta, WF_LONG_TIMEOUT);

	return lenghtResponse;
}

uint32_t wiFlyExit(char* bufferResponse)
{
	return wiflySendCommand(WF_COM_ACT_EXIT, bufferResponse, WF_LONG_TIMEOUT);
}

void wiFlyJoinWLAN(char* bufferResponse, char* ssid, int authmode, char* pass)
{
	char command[100];
	bufferClear( command, 100 );
	
	switch (authmode)
	{
		case 1:
			strcpy(command, WF_COM_SET_WLAN_KEY);
			strcat(command, pass);
			wiflySendCommand(command, bufferResponse, WF_SET_TIMEOUT);
			break;
		case 2:
			strcpy(command, WF_COM_SET_WLAN_PHRASE);
			strcat(command, pass);
			wiflySendCommand(command, bufferResponse, WF_SET_TIMEOUT);
			break;
	}

	bufferClear( command, 100 );
	bufferClear(bufferResponse, 1000);
	strcpy(command, WF_COM_ACT_JOIN_SSID);
	strcat(command, ssid);
	wiflySendCommand(command, bufferResponse, WF_JOIN_TIMEOUT);
}

uint32_t wiFlyPing(char* bufferRespuesta, char* ip, int numPings)
{
	char command[25];
	bufferClear( command, 25 );

	sprintf(command, WF_COM_ACT_PING, ip, numPings);
	return wiflySendCommand(command, bufferRespuesta, WF_LONG_TIMEOUT);
}


//Functions Status Commands

uint32_t wiFlyShowRSSI(char* bufferResponse)
{
	return wiflySendCommand(WF_COM_SHOW_RSSI, bufferResponse, WF_DEFAULT_TIMEOUT);
}


//Functions Get Commands

uint32_t wiFlyGetIP(char* bufferResponse)
{
	return wiflySendCommand(WF_COM_GET_CURRENT_IP, bufferResponse, WF_DEFAULT_TIMEOUT);
}

uint32_t wiFlyGetChannel(char* bufferResponse)
{
	return wiflySendCommand(WF_COM_GET_WLAN, bufferResponse, WF_DEFAULT_TIMEOUT);
}

uint32_t wiFlyShowUpTime(char* bufferResponse)
{
	return wiflySendCommand(WF_COM_SHOW_TIME , bufferResponse, WF_DEFAULT_TIMEOUT);
}


//Functions Set Commands

uint32_t wiFlySetBaudRate(char* bufferResponse, uint16_t newBaudRate)
{
	uint32_t codeReturn;
	char command[25];
	bufferClear( command, 25 );

	sprintf(command, WF_COM_SET_UART_BAUD, newBaudRate);
	codeReturn = wiflySendCommand(command, bufferResponse, WF_SET_TIMEOUT);
	codeReturn = wiflySendCommand(WF_COM_ACT_SAVE, bufferResponse, WF_SET_TIMEOUT);
	codeReturn = wiflySendCommand(WF_COM_ACT_REBOOT, bufferResponse, WF_DOUBLE_TIMEOUT);

	//Init with the new baudrate
	UARTInit(WF_UART, newBaudRate);

	return codeReturn;
}


