/*
 ============================================================================
 Name        : logTerminal.c
 Author      : Oscar Garcia Sanchez
 Version     : 1
 Copyright   : none
 Description : LogTerminal Functions
 ============================================================================
 */

#include "stdio.h"
#include "string.h"
#include "type.h"
#include "uart.h"
#include "FreeRTOS.h"
#include "semphr.h"
#include "LPC17xx.h"

#include "UARTprintf.h"
#include "logTerminal.h"

xSemaphoreHandle xMutexTerminal;									//Mutex para evitar accesos simultaneos al terminal

void logTerminal(char* cadena)
{
	while(xSemaphoreTake(xMutexTerminal,0) != pdTRUE)
	{
		delayMs(100);												//Si alguien esta escribiendo por el terminal, esperamos un poco para ver si se libera
	}
	UARTprintfln(UART_OUTPUT_TERMINAL, cadena);
	xSemaphoreGive( xMutexTerminal );								//Hemos terminado de escribir, liberamos el mutex
}

void logTerminalNmbr(char* cadena, uint16_t numero)
{
	while(xSemaphoreTake( xMutexTerminal, 0 ) != pdTRUE)
	{
		delayMs(100);												//Si alguien esta escribiendo por el terminal, esperamos un poco para ver si se libera
	}
	UARTprintfnmbrln(UART_OUTPUT_TERMINAL, cadena, numero);
	xSemaphoreGive( xMutexTerminal );								//Hemos terminado de escribir, liberamos el mutex
}

void logTerminalFloat(char* cadena, float numero)
{
	while(xSemaphoreTake( xMutexTerminal, 0 ) != pdTRUE)
	{
		delayMs(300);												//Si alguien esta escribiendo por el terminal, esperamos un poco para ver si se libera
	}
	UARTprintfnmbrfloatln(UART_OUTPUT_TERMINAL, cadena, numero);
	xSemaphoreGive( xMutexTerminal );							 	//Hemos terminado de escribir, liberamos el mutex
}

void logTerminalInit()
{
	UARTInit(UART_OUTPUT_TERMINAL, UART_OUTPUT_BR);					//Inicializamos el UART
	xMutexTerminal = xSemaphoreCreateMutex();						//Creamos el mutex
	logTerminal("Output Terminal Online");							//Mensaje de inicio
}
